'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.processInputs = undefined;

var _command = require('@oclif/command');

var _liskTransactions = require('@liskhq/lisk-transactions');

var _liskTransactions2 = _interopRequireDefault(_liskTransactions);

var _base = require('../../../base');

var _base2 = _interopRequireDefault(_base);

var _flags = require('../../../utils/flags');

var _flags2 = _interopRequireDefault(_flags);

var _input = require('../../../utils/input');

var _input2 = _interopRequireDefault(_input);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const processInputs = exports.processInputs = () => ({ passphrase, secondPassphrase }) => _liskTransactions2.default.registerSecondPassphrase({
	passphrase,
	secondPassphrase
}); /*
     * LiskHQ/lisk-commander
     * Copyright © 2017–2018 Lisk Foundation
     *
     * See the LICENSE file at the top-level directory of this distribution
     * for licensing information.
     *
     * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
     * no part of this software, including this file, may be copied, modified,
     * propagated, or distributed except according to the terms contained in the
     * LICENSE file.
     *
     * Removal or modification of this copyright notice is prohibited.
     *
     */
class SecondPassphraseCommand extends _base2.default {
	async run() {
		const {
			flags: {
				passphrase: passphraseSource,
				'second-passphrase': secondPassphraseSource,
				'no-signature': noSignature
			}
		} = this.parse(SecondPassphraseCommand);

		const processFunction = processInputs();

		const inputs = noSignature ? await (0, _input2.default)({
			passphrase: null,
			secondPassphrase: {
				source: secondPassphraseSource,
				repeatPrompt: true
			}
		}) : await (0, _input2.default)({
			passphrase: {
				source: passphraseSource,
				repeatPrompt: true
			},
			secondPassphrase: {
				source: secondPassphraseSource,
				repeatPrompt: true
			}
		});
		const result = processFunction(inputs);
		this.print(result);
	}
}

exports.default = SecondPassphraseCommand;
SecondPassphraseCommand.flags = Object.assign({}, _base2.default.flags, {
	passphrase: _command.flags.string(_flags2.default.passphrase),
	'second-passphrase': _command.flags.string(_flags2.default.secondPassphrase),
	'no-signature': _command.flags.boolean(_flags2.default.noSignature)
});

SecondPassphraseCommand.description = `
Creates a transaction which will register a second passphrase for the account if broadcast to the network.
`;

SecondPassphraseCommand.examples = ['transaction:create:second-passphrase'];